import { Align, Direction, Display, Edge, FlexDirection, Gutter, Justify, Overflow, PositionType, Wrap, loadYoga } from 'yoga-layout/load';
export const Yoga = await loadYoga();
function createYogaNode() {
    return Yoga.Node.create();
}
function computeAndLayout(node) {
    if (node?.isLeaf && node?.yogaNode) {
        node.yogaNode.markDirty();
    }
    if (!node?.rootYogaNode) {
        return;
    }
    const rootView = node._rootView || node;
    if (rootView.pauseLayoutUpdates)
        return;
    node.rootYogaNode?.calculateLayout(node.rootYogaNode.getWidth().value, node.rootYogaNode.getHeight().value, Yoga.DIRECTION_LTR);
    rootView.applyLayout();
}
/**

   * Flex Prop Types

   * @see https://reactnative.dev/docs/flexbox

   * @see https://reactnative.dev/docs/layout-props

   */
const ConvertToYogaValue = {
    alignContent: (value) => {
        switch (value) {
            case 'flex-start':
                return Align.FlexStart;
            case 'center':
                return Align.Center;
            case 'flex-end':
                return Align.FlexEnd;
            case 'stretch':
                return Align.Stretch;
            case 'space-between':
                return Align.SpaceBetween;
            case 'space-around':
                return Align.SpaceAround;
            default:
                return undefined;
        }
    },
    alignItems: (value) => {
        // Assuming FlexAlignType maps to Yoga Align directly
        return ConvertToYogaValue.alignContent(value); // Use `alignContent` converter if `alignItems` is similar
    },
    alignSelf: (value) => {
        // Same mapping as alignContent
        return ConvertToYogaValue.alignContent(value);
    },
    aspectRatio: (value) => {
        return typeof value === 'number' ? value : undefined; // Aspect Ratio remains a number
    },
    borderBottomWidth: (value) => value,
    borderEndWidth: (value) => value,
    borderLeftWidth: (value) => value,
    borderRightWidth: (value) => value,
    borderStartWidth: (value) => value,
    borderTopWidth: (value) => value,
    borderWidth: (value) => value,
    bottom: (value) => value,
    display: (value) => {
        switch (value) {
            case 'flex':
                return Display.Flex;
            case 'none':
                return Display.None;
            default:
                return undefined;
        }
    },
    end: (value) => value,
    flex: (value) => value,
    flexBasis: (value) => value,
    flexDirection: (value) => {
        switch (value) {
            case 'row':
                return FlexDirection.Row;
            case 'column':
                return FlexDirection.Column;
            case 'row-reverse':
                return FlexDirection.RowReverse;
            case 'column-reverse':
                return FlexDirection.ColumnReverse;
            default:
                return undefined;
        }
    },
    rowGap: (value) => value,
    gap: (value) => value,
    columnGap: (value) => value,
    flexGrow: (value) => value,
    flexShrink: (value) => value,
    flexWrap: (value) => {
        switch (value) {
            case 'wrap':
                return Wrap.Wrap;
            case 'nowrap':
                return Wrap.NoWrap;
            case 'wrap-reverse':
                return Wrap.WrapReverse;
            default:
                return undefined;
        }
    },
    height: (value) => value,
    justifyContent: (value) => {
        switch (value) {
            case 'flex-start':
                return Justify.FlexStart;
            case 'center':
                return Justify.Center;
            case 'flex-end':
                return Justify.FlexEnd;
            case 'space-between':
                return Justify.SpaceBetween;
            case 'space-around':
                return Justify.SpaceAround;
            case 'space-evenly':
                return Justify.SpaceEvenly;
            default:
                return undefined;
        }
    },
    left: (value) => value,
    margin: (value) => value,
    marginBlock: (value) => value,
    marginBlockEnd: (value) => value,
    marginBlockStart: (value) => value,
    marginBottom: (value) => value,
    marginEnd: (value) => value,
    marginHorizontal: (value) => value,
    marginInline: (value) => value,
    marginInlineEnd: (value) => value,
    marginInlineStart: (value) => value,
    marginLeft: (value) => value,
    marginRight: (value) => value,
    marginStart: (value) => value,
    marginTop: (value) => value,
    marginVertical: (value) => value,
    maxHeight: (value) => value,
    maxWidth: (value) => value,
    minHeight: (value) => value,
    minWidth: (value) => value,
    overflow: (value) => {
        switch (value) {
            case 'visible':
                return Overflow.Visible;
            case 'hidden':
                return Overflow.Hidden;
            case 'scroll':
                return Overflow.Scroll;
            default:
                return undefined;
        }
    },
    padding: (value) => value,
    paddingBottom: (value) => value,
    paddingBlock: (value) => value,
    paddingBlockEnd: (value) => value,
    paddingBlockStart: (value) => value,
    paddingEnd: (value) => value,
    paddingHorizontal: (value) => value,
    paddingInline: (value) => value,
    paddingInlineEnd: (value) => value,
    paddingInlineStart: (value) => value,
    paddingLeft: (value) => value,
    paddingRight: (value) => value,
    paddingStart: (value) => value,
    paddingTop: (value) => value,
    paddingVertical: (value) => value,
    position: (value) => {
        switch (value) {
            case 'absolute':
                return PositionType.Absolute;
            case 'static':
                return PositionType.Static;
            default:
                return PositionType.Relative;
        }
    },
    right: (value) => value,
    start: (value) => value,
    top: (value) => value,
    width: (value) => value,
    direction: (value) => {
        switch (value) {
            case 'inherit':
                return Direction.Inherit;
            case 'ltr':
                return Direction.LTR;
            case 'rtl':
                return Direction.RTL;
            default:
                return undefined;
        }
    },
};
const ConvertFromYogaValue = {
    alignContent: (value) => {
        switch (value) {
            case Align.FlexStart:
                return 'flex-start';
            case Align.Center:
                return 'center';
            case Align.FlexEnd:
                return 'flex-end';
            case Align.Stretch:
                return 'stretch';
            case Align.SpaceBetween:
                return 'space-between';
            case Align.SpaceAround:
                return 'space-around';
            default:
                return undefined;
        }
    },
    alignItems: (value) => {
        switch (value) {
            case Align.FlexStart:
                return 'flex-start';
            case Align.Center:
                return 'center';
            case Align.FlexEnd:
                return 'flex-end';
            case Align.Stretch:
                return 'stretch';
            default:
                return undefined;
        }
    },
    alignSelf: (value) => {
        switch (value) {
            case Align.FlexStart:
                return 'flex-start';
            case Align.Center:
                return 'center';
            case Align.FlexEnd:
                return 'flex-end';
            case Align.Stretch:
                return 'stretch';
            default:
                return undefined;
        }
    },
    aspectRatio: (value) => value,
    borderBottomWidth: (value) => value,
    borderEndWidth: (value) => value,
    borderLeftWidth: (value) => value,
    borderRightWidth: (value) => value,
    borderStartWidth: (value) => value,
    borderTopWidth: (value) => value,
    borderWidth: (value) => value,
    bottom: (value) => value,
    display: (value) => {
        switch (value) {
            case Display.Flex:
                return 'flex';
            case Display.None:
                return 'none';
            default:
                return undefined;
        }
    },
    end: (value) => value,
    flex: (value) => value,
    flexBasis: (value) => value,
    flexDirection: (value) => {
        switch (value) {
            case FlexDirection.Row:
                return 'row';
            case FlexDirection.Column:
                return 'column';
            case FlexDirection.RowReverse:
                return 'row-reverse';
            case FlexDirection.ColumnReverse:
                return 'column-reverse';
            default:
                return undefined;
        }
    },
    rowGap: (value) => value,
    gap: (value) => value,
    columnGap: (value) => value,
    flexGrow: (value) => value,
    flexShrink: (value) => value,
    flexWrap: (value) => {
        switch (value) {
            case Wrap.Wrap:
                return 'wrap';
            case Wrap.NoWrap:
                return 'nowrap';
            case Wrap.WrapReverse:
                return 'wrap-reverse';
            default:
                return undefined;
        }
    },
    height: (value) => value,
    justifyContent: (value) => {
        switch (value) {
            case Justify.FlexStart:
                return 'flex-start';
            case Justify.Center:
                return 'center';
            case Justify.FlexEnd:
                return 'flex-end';
            case Justify.SpaceBetween:
                return 'space-between';
            case Justify.SpaceAround:
                return 'space-around';
            case Justify.SpaceEvenly:
                return 'space-evenly';
            default:
                return undefined;
        }
    },
    left: (value) => value,
    margin: (value) => value,
    marginBlock: (value) => value,
    marginBlockEnd: (value) => value,
    marginBlockStart: (value) => value,
    marginBottom: (value) => value,
    marginEnd: (value) => value,
    marginHorizontal: (value) => value,
    marginInline: (value) => value,
    marginInlineEnd: (value) => value,
    marginInlineStart: (value) => value,
    marginLeft: (value) => value,
    marginRight: (value) => value,
    marginStart: (value) => value,
    marginTop: (value) => value,
    marginVertical: (value) => value,
    maxHeight: (value) => value,
    maxWidth: (value) => value,
    minHeight: (value) => value,
    minWidth: (value) => value,
    overflow: (value) => {
        switch (value) {
            case Overflow.Visible:
                return 'visible';
            case Overflow.Hidden:
                return 'hidden';
            case Overflow.Scroll:
                return 'scroll';
            default:
                return undefined;
        }
    },
    padding: (value) => value,
    paddingBottom: (value) => value,
    paddingBlock: (value) => value,
    paddingBlockEnd: (value) => value,
    paddingBlockStart: (value) => value,
    paddingEnd: (value) => value,
    paddingHorizontal: (value) => value,
    paddingInline: (value) => value,
    paddingInlineEnd: (value) => value,
    paddingInlineStart: (value) => value,
    paddingLeft: (value) => value,
    paddingRight: (value) => value,
    paddingStart: (value) => value,
    paddingTop: (value) => value,
    paddingVertical: (value) => value,
    position: (value) => {
        switch (value) {
            case PositionType.Absolute:
                return 'absolute';
            case PositionType.Relative:
                return 'relative';
            case PositionType.Static:
                return 'static';
            default:
                return 'relative';
        }
    },
    right: (value) => value,
    start: (value) => value,
    top: (value) => value,
    width: (value) => value,
    direction: (value) => {
        switch (value) {
            case Direction.Inherit:
                return 'inherit';
            case Direction.LTR:
                return 'ltr';
            case Direction.RTL:
                return 'rtl';
            default:
                return undefined;
        }
    },
};
const flexStyleKeys = [
    'alignContent',
    'alignItems',
    'alignSelf',
    'aspectRatio',
    'borderBottomWidth',
    'borderEndWidth',
    'borderLeftWidth',
    'borderRightWidth',
    'borderStartWidth',
    'borderTopWidth',
    'borderWidth',
    'bottom',
    'display',
    'end',
    'flex',
    'flexBasis',
    'flexDirection',
    'rowGap',
    'gap',
    'columnGap',
    'flexGrow',
    'flexShrink',
    'flexWrap',
    'height',
    'justifyContent',
    'left',
    'margin',
    'marginBlock',
    'marginBlockEnd',
    'marginBlockStart',
    'marginBottom',
    'marginEnd',
    'marginHorizontal',
    'marginInline',
    'marginInlineEnd',
    'marginInlineStart',
    'marginLeft',
    'marginRight',
    'marginStart',
    'marginTop',
    'marginVertical',
    'maxHeight',
    'maxWidth',
    'minHeight',
    'minWidth',
    'overflow',
    'padding',
    'paddingBottom',
    'paddingBlock',
    'paddingBlockEnd',
    'paddingBlockStart',
    'paddingEnd',
    'paddingHorizontal',
    'paddingInline',
    'paddingInlineEnd',
    'paddingInlineStart',
    'paddingLeft',
    'paddingRight',
    'paddingStart',
    'paddingTop',
    'paddingVertical',
    'position',
    'right',
    'start',
    'top',
    'width',
    'direction',
];
const Setters = {
    alignContent(yogaNode, alignContent) {
        yogaNode.setAlignContent(alignContent);
    },
    alignItems(yogaNode, alignItems) {
        yogaNode.setAlignItems(alignItems);
    },
    alignSelf(yogaNode, alignSelf) {
        yogaNode.setAlignSelf(alignSelf);
    },
    aspectRatio(yogaNode, aspectRatio) {
        yogaNode.setAspectRatio(aspectRatio);
    },
    borderLeftWidth(yogaNode, borderWidth) {
        yogaNode.setBorder(Edge.Left, borderWidth);
    },
    borderRightWidth(yogaNode, borderWidth) {
        yogaNode.setBorder(Edge.Right, borderWidth);
    },
    borderTopWidth(yogaNode, borderWidth) {
        yogaNode.setBorder(Edge.Top, borderWidth);
    },
    borderBottomWidth(yogaNode, borderWidth) {
        yogaNode.setBorder(Edge.Bottom, borderWidth);
    },
    borderWidth(yogaNode, borderWidth) {
        yogaNode.setBorder(Edge.All, borderWidth);
    },
    direction(yogaNode, direction) {
        yogaNode.setDirection(direction);
    },
    display(yogaNode, display) {
        yogaNode.setDisplay(display);
    },
    flex(yogaNode, flex) {
        yogaNode.setFlex(flex);
    },
    flexBasis(yogaNode, flexBasis) {
        yogaNode.setFlexBasis(flexBasis);
    },
    flexBasisAuto(yogaNode) {
        yogaNode.setFlexBasisAuto();
    },
    flexDirection(yogaNode, flexDirection) {
        yogaNode.setFlexDirection(flexDirection);
    },
    flexGrow(yogaNode, flexGrow) {
        yogaNode.setFlexGrow(flexGrow);
    },
    flexShrink(yogaNode, flexShrink) {
        yogaNode.setFlexShrink(flexShrink);
    },
    flexWrap(yogaNode, flexWrap) {
        yogaNode.setFlexWrap(flexWrap);
    },
    width(yogaNode, height) {
        yogaNode.setWidth(height);
    },
    height(yogaNode, height) {
        yogaNode.setHeight(height);
    },
    justifyContent(yogaNode, justifyContent) {
        yogaNode.setJustifyContent(justifyContent);
    },
    gap(yogaNode, gapLength) {
        yogaNode.setGap(Gutter.All, gapLength);
    },
    rowGap(yogaNode, gapLength) {
        yogaNode.setGap(Gutter.Row, gapLength);
    },
    columnGap(yogaNode, gapLength) {
        yogaNode.setGap(Gutter.Column, gapLength);
    },
    marginLeft(yogaNode, margin) {
        yogaNode.setMargin(Edge.Left, margin);
    },
    marginRight(yogaNode, margin) {
        yogaNode.setMargin(Edge.Right, margin);
    },
    marginTop(yogaNode, margin) {
        yogaNode.setMargin(Edge.Top, margin);
    },
    marginBottom(yogaNode, margin) {
        yogaNode.setMargin(Edge.Bottom, margin);
    },
    maxHeight(yogaNode, maxHeight) {
        yogaNode.setMaxHeight(maxHeight);
    },
    maxWidth(yogaNode, maxWidth) {
        yogaNode.setMaxWidth(maxWidth);
    },
    minHeight(yogaNode, minHeight) {
        yogaNode.setMinHeight(minHeight);
    },
    minWidth(yogaNode, minWidth) {
        yogaNode.setMinWidth(minWidth);
    },
    overflow(yogaNode, overflow) {
        yogaNode.setOverflow(overflow);
    },
    paddingLeft(yogaNode, padding) {
        yogaNode.setPadding(Edge.Left, padding);
    },
    paddingRight(yogaNode, padding) {
        yogaNode.setPadding(Edge.Right, padding);
    },
    paddingTop(yogaNode, padding) {
        yogaNode.setPadding(Edge.Top, padding);
    },
    paddingBottom(yogaNode, padding) {
        yogaNode.setPadding(Edge.Bottom, padding);
    },
    padding(yogaNode, padding) {
        yogaNode.setPadding(Edge.All, padding);
    },
    top(yogaNode, top) {
        yogaNode.setPosition(Edge.Top, top);
    },
    left(yogaNode, left) {
        yogaNode.setPosition(Edge.Left, left);
    },
    right(yogaNode, right) {
        yogaNode.setPosition(Edge.Right, right);
    },
    bottom(yogaNode, bottom) {
        yogaNode.setPosition(Edge.Bottom, bottom);
    },
    end(yogaNode, end) {
        yogaNode.setPosition(Edge.End, end);
    },
    start(yogaNode, start) {
        yogaNode.setPosition(Edge.Start, start);
    },
    marginBlock(yogaNode, margin) {
        yogaNode.setMargin(Edge.Vertical, margin);
    },
    marginBlockEnd(yogaNode, margin) {
        yogaNode.setMargin(Edge.Bottom, margin);
    },
    marginBlockStart(yogaNode, margin) {
        yogaNode.setMargin(Edge.Top, margin);
    },
    paddingBlock(yogaNode, padding) {
        yogaNode.setPadding(Edge.Vertical, padding);
    },
    paddingBlockEnd(yogaNode, padding) {
        yogaNode.setPadding(Edge.Bottom, padding);
    },
    paddingBlockStart(yogaNode, padding) {
        yogaNode.setPadding(Edge.Top, padding);
    },
    paddingHorizontal(yogaNode, padding) {
        yogaNode.setPadding(Edge.Horizontal, padding);
    },
    paddingVertical(yogaNode, padding) {
        yogaNode.setPadding(Edge.Vertical, padding);
    },
    marginVertical(yogaNode, margin) {
        yogaNode.setMargin(Edge.Vertical, margin);
    },
    marginHorizontal(yogaNode, margin) {
        yogaNode.setMargin(Edge.Horizontal, margin);
    },
    marginStart(yogaNode, margin) {
        yogaNode.setMargin(Edge.Start, margin);
    },
    marginEnd(yogaNode, margin) {
        yogaNode.setMargin(Edge.End, margin);
    },
    paddingStart(yogaNode, padding) {
        yogaNode.setPadding(Edge.Start, padding);
    },
};
export const Layout = {
    createYogaNode,
    ConvertToYogaValue,
    ConvertFromYogaValue,
    propertiesList: flexStyleKeys,
    computeAndLayout,
    Setters,
};
//# sourceMappingURL=index.js.map